@@ -1,4 +1,4 @@
-# $Id: Request.pm 36638 2012-03-03 14:33:20Z wsl $
+# $Id: Request.pm 42268 2014-09-22 14:05:34Z wsl $
 # $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Success/Request.pm $
 
 use strict;
@@ -50,3 +50,18 @@ field cred_url => sub {
 		return $self->script_url . '/status';
 	}
 };
+
+field expiration_warning => sub {
+	my $self = shift;
+	# Only bother the user when initially signing in
+	return undef if $self->new_session eq $self->cur_session;
+	my $exp = eval { $self->dir->expiration($self->uid) };
+	warn $@ if $@;
+	return $exp;
+};
+
+field redirect_ok => sub {
+	my $self = shift;
+	return ($self->effective_warn eq 'false' || $self->nonce)
+		&& !$self->expiration_warning;
+};
